==> jc-1.4.0.tar.gz: java/util/EventListenerProxy.h <==
// public abstract class java.util.EventListenerProxy

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5aac94d3604b130b java_util_EventListenerProxy

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_EventListenerProxy_H_
#define _JC_java_util_EventListenerProxy_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_EventListener$object;

// Typedefs
typedef struct _jc_java_util_EventListenerProxy$sub_refs	_jc_java_util_EventListenerProxy$sub_refs;
typedef struct _jc_java_util_EventListenerProxy$sub_nonrefs	_jc_java_util_EventListenerProxy$sub_nonrefs;
typedef struct _jc_java_util_EventListenerProxy$refs	_jc_java_util_EventListenerProxy$refs;
typedef struct _jc_java_util_EventListenerProxy$nonrefs	_jc_java_util_EventListenerProxy$nonrefs;
typedef struct _jc_java_util_EventListenerProxy$object	_jc_java_util_EventListenerProxy$object;

typedef const struct _jc_java_util_EventListenerProxy$vmethods	_jc_java_util_EventListenerProxy$vmethods;
typedef const struct _jc_java_util_EventListenerProxy$vtable	_jc_java_util_EventListenerProxy$vtable;
typedef const struct _jc_java_util_EventListenerProxy$vtype	_jc_java_util_EventListenerProxy$vtype;

// Constructors
extern void _jc_java_util_EventListenerProxy$method$_init$4405159b95a850b3(_jc_env *, struct _jc_java_util_EventListenerProxy$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_java_util_EventListenerProxy$method$getListener$5e6da303a677b902(_jc_env *, struct _jc_java_util_EventListenerProxy$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_EventListenerProxy$method_info$getListener$5e6da303a677b902;

// Virtual methods structure
struct _jc_java_util_EventListenerProxy$vmethods {
	struct _jc_object	*(*getListener$5e6da303a677b902)(_jc_env *, struct _jc_java_util_EventListenerProxy$object *);
};

// Vtable
struct _jc_java_util_EventListenerProxy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventListenerProxy$vmethods	java_util_EventListenerProxy;
};

// Vtype
struct _jc_java_util_EventListenerProxy$vtype {
	_jc_type			type;
	_jc_java_util_EventListenerProxy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_EventListenerProxy$sub_refs {
	struct _jc_object	*listener;
};

// Reference instance fields (object)
struct _jc_java_util_EventListenerProxy$refs {
    _jc_java_util_EventListenerProxy$sub_refs	java_util_EventListenerProxy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_EventListenerProxy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_EventListenerProxy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventListenerProxy$sub_nonrefs	java_util_EventListenerProxy;
};

// Object instance structure
struct _jc_java_util_EventListenerProxy$object {
	_jc_java_util_EventListenerProxy$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_EventListenerProxy$vtype	*vtype;
	_jc_java_util_EventListenerProxy$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_EventListenerProxy$vtype _jc_java_util_EventListenerProxy$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_EventListenerProxy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_EventListenerProxy$class_object;

#endif	/* _JC_java_util_EventListenerProxy_H_ */

==> jc-1.4.6.tar.gz: java/util/EventListenerProxy.h <==
// public abstract class java.util.EventListenerProxy

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5aac94d3604b130b java_util_EventListenerProxy

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_EventListenerProxy_H_
#define _JC_java_util_EventListenerProxy_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_EventListener$object;

// Typedefs
typedef struct _jc_java_util_EventListenerProxy$sub_refs	_jc_java_util_EventListenerProxy$sub_refs;
typedef struct _jc_java_util_EventListenerProxy$sub_nonrefs	_jc_java_util_EventListenerProxy$sub_nonrefs;
typedef struct _jc_java_util_EventListenerProxy$refs	_jc_java_util_EventListenerProxy$refs;
typedef struct _jc_java_util_EventListenerProxy$nonrefs	_jc_java_util_EventListenerProxy$nonrefs;
typedef struct _jc_java_util_EventListenerProxy$object	_jc_java_util_EventListenerProxy$object;

typedef const struct _jc_java_util_EventListenerProxy$vmethods	_jc_java_util_EventListenerProxy$vmethods;
typedef const struct _jc_java_util_EventListenerProxy$vtable	_jc_java_util_EventListenerProxy$vtable;
typedef const struct _jc_java_util_EventListenerProxy$vtype	_jc_java_util_EventListenerProxy$vtype;

// Constructors
extern void _jc_java_util_EventListenerProxy$method$_init$4405159b95a850b3(_jc_env *, struct _jc_java_util_EventListenerProxy$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_util_EventListenerProxy$method$getListener$5e6da303a677b902(_jc_env *, struct _jc_java_util_EventListenerProxy$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_EventListenerProxy$method_info$getListener$5e6da303a677b902;

// Virtual methods structure
struct _jc_java_util_EventListenerProxy$vmethods {
	struct _jc_object	*(*getListener$5e6da303a677b902)(_jc_env *, struct _jc_java_util_EventListenerProxy$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_EventListenerProxy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventListenerProxy$vmethods	java_util_EventListenerProxy;
};

// Vtype
struct _jc_java_util_EventListenerProxy$vtype {
	_jc_type			type;
	_jc_java_util_EventListenerProxy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_EventListenerProxy$sub_refs {
	struct _jc_object	*listener;
};

// Reference instance fields (object)
struct _jc_java_util_EventListenerProxy$refs {
    _jc_java_util_EventListenerProxy$sub_refs	java_util_EventListenerProxy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_EventListenerProxy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_EventListenerProxy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventListenerProxy$sub_nonrefs	java_util_EventListenerProxy;
};

// Object instance structure
struct _jc_java_util_EventListenerProxy$object {
	_jc_java_util_EventListenerProxy$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_EventListenerProxy$vtype	*vtype;
	_jc_java_util_EventListenerProxy$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_EventListenerProxy$vtype _jc_java_util_EventListenerProxy$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_EventListenerProxy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_EventListenerProxy$class_object;

#endif	/* _JC_java_util_EventListenerProxy_H_ */
